@@ -12,13 +12,13 @@
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
    +----------------------------------------------------------------------+
-   | Author: Stig Sther Bakken <ssb@php.net>                             |
+   | Author: Stig Sæther Bakken <ssb@php.net>                             |
    +----------------------------------------------------------------------+
 */
 
 /* $Id$ */
 
-#define CONFIGURE_COMMAND " './configure'  '--with-config-file-path=/usr/pkg/etc' '--with-config-file-scan-dir=/usr/pkg/etc/php.d' '--sysconfdir=/usr/pkg/etc' '--localstatedir=/var' '--without-mysqli' '--without-iconv' '--without-pear' '--without-sqlite3' '--disable-posix' '--disable-opcache' '--disable-pdo' '--disable-json' '--enable-cgi' '--enable-mysqlnd' '--enable-xml' '--with-libxml-dir=/usr/pkg' '--enable-ipv6' '--with-openssl=/usr' '--with-readline=/usr/pkg' '--without-pcre-jit' '--prefix=/usr/pkg' '--build=armv7--netbsdelf-eabihf' '--host=armv7--netbsdelf-eabihf' '--mandir=/usr/pkg/man' '--enable-option-checking=yes' 'build_alias=armv7--netbsdelf-eabihf' 'host_alias=armv7--netbsdelf-eabihf' 'LIBS=' 'CXXCPP=cpp'"
+#define CONFIGURE_COMMAND " './configure'  '--with-pcre-dir=/usr/pkg' '--with-config-file-path=/usr/pkg/etc' '--with-config-file-scan-dir=/usr/pkg/etc/php.d' '--sysconfdir=/usr/pkg/etc' '--localstatedir=/var' '--without-mysqli' '--without-iconv' '--without-pear' '--without-sqlite3' '--disable-posix' '--disable-opcache' '--disable-pdo' '--disable-json' '--enable-cgi' '--enable-mysqlnd' '--enable-xml' '--with-libxml-dir=/usr/pkg' '--with-pcre-regex=/usr/pkg' '--enable-ipv6' '--with-openssl=/usr' '--with-readline=/usr/pkg' '--prefix=/usr/pkg' '--build=x86_64--netbsd' '--host=x86_64--netbsd' '--mandir=/usr/pkg/man' 'build_alias=x86_64--netbsd' 'host_alias=x86_64--netbsd' 'LIBS=' 'CXXCPP=cpp'"
 #define PHP_ADA_INCLUDE		""
 #define PHP_ADA_LFLAGS		""
 #define PHP_ADA_LIBS		""
@@ -60,7 +60,7 @@
 #define PHP_PGSQL_INCLUDE	""
 #define PHP_PGSQL_LFLAGS	""
 #define PHP_PGSQL_LIBS		""
-#define PHP_PROG_SENDMAIL	"/usr/pkg/bin/sendmail"
+#define PHP_PROG_SENDMAIL	"/usr/sbin/sendmail"
 #define PHP_SOLID_INCLUDE	""
 #define PHP_SOLID_LIBS		""
 #define PHP_EMPRESS_INCLUDE	""
@@ -77,7 +77,7 @@
 #define PHP_BIRDSTEP_LIBS        ""
 #define PEAR_INSTALLDIR         ""
 #define PHP_INCLUDE_PATH	".:"
-#define PHP_EXTENSION_DIR       "/usr/pkg/lib/php/20160303"
+#define PHP_EXTENSION_DIR       "/usr/pkg/lib/php/20170718"
 #define PHP_PREFIX              "/usr/pkg"
 #define PHP_BINDIR              "/usr/pkg/bin"
 #define PHP_SBINDIR             "/usr/pkg/sbin"
@@ -89,3 +89,4 @@
 #define PHP_CONFIG_FILE_PATH    "/usr/pkg/etc"
 #define PHP_CONFIG_FILE_SCAN_DIR    "/usr/pkg/etc/php.d"
 #define PHP_SHLIB_SUFFIX        "so"
+#define PHP_SHLIB_EXT_PREFIX    ""
